// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Pdf.Annotations;
using GrapeCity.Documents.Pdf.Actions;

namespace DsPdfWeb.Demos.Basics
{
    // このサンプルは、ページに添付ファイルの注釈を作成する方法を示します。
    // 文書レベルのファイル添付を示す DocAttachments サンプルも参照してください。
    public class FileAttachments
    {
        public int CreatePDF(Stream stream)
        {
            var doc = new GcPdfDocument();
            var page = doc.NewPage();
            var g = page.Graphics;

            var rc = Common.Util.AddNote(
                "このページには、サンプルの Resources/Images フォルダにあるいくつかのファイルが添付されています。\n" +
                "添付ファイルが表示できない場合があるため、クリック可能な場所を示す四角形を描画しています。",
                page);
            var ip = new PointF(rc.X, rc.Bottom + 9);
            var attSize = new SizeF(36, 12);
            var gap = 8;
            var files = new string[]
            {
                "tudor.jpg",
                "sea.jpg",
                "puffins.jpg",
                "lavender.jpg",
                "skye.jpg",
                "fiord.jpg",
                "newfoundland.jpg"
            };
            foreach (string fn in files)
            {
                var file = Path.Combine("Resources", "Images", fn);
                var faa = new FileAttachmentAnnotation()
                {
                    Color = Color.FromArgb(unchecked((int)0xFFc540a5)),
                    UserName = "作成者1",
                    Rect = new RectangleF(ip.X, ip.Y, attSize.Width, attSize.Height),
                    Contents = "添付ファイル: " + file,
                    Icon = FileAttachmentAnnotationIcon.Paperclip,
                    File = FileSpecification.FromEmbeddedFile(EmbeddedFileStream.FromFile(doc, file)),
                };
                page.Annotations.Add(faa);
                g.FillRectangle(faa.Rect, Color.FromArgb(unchecked((int)0xFF40c5a3)));
                g.DrawRectangle(faa.Rect, Color.FromArgb(unchecked((int)0xFF6040c5)));
                ip.Y += attSize.Height + gap;
            }
            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
